Friends
=======

.. autoclass:: steampak.libsteam.resources.friends.Friends
    :inherited-members:


Friend Tag
----------

.. autoclass:: steampak.libsteam.resources.friends.FriendTag
    :inherited-members:


Friend Filter
-------------

.. autoclass:: steampak.libsteam.resources.base.FriendFilter
    :inherited-members:
    :undoc-members:
